Lab and Downward Lab
====================

**Lab** is a Python package for evaluating solvers on benchmark sets.
Experiments can run on a single machine or on a computer cluster. The
package also contains code for parsing results and creating reports.

The **Downward Lab** Python package facilitates running experiments for
the `Fast Downward <http://www.fast-downward.org>`_ planning system. It
uses the generic experimentation package **Lab**. Currently, Lab and
Downward Lab are distributed together.

**Code**: https://github.com/aibasel/lab

**Documentation**: https://lab.readthedocs.io

**Cite**: please cite Downward Lab by using

::

    @Misc{seipp-et-al-zenodo2017,
      author =       "Jendrik Seipp and Florian Pommerening and
                      Silvan Sievers and Malte Helmert",
      title =        "{Downward} {Lab}",
      publisher =    "Zenodo",
      year =         "2017",
      howpublished = "\url{https://doi.org/10.5281/zenodo.790461}"
    }
